from django.test import TestCase

from functions import get_test_location, create_user, create_visit, create_location
from web.forms import AppointmentAddForm
from web.forms import AppointmentEditForm
from web.models import Appointment, Worker


class AppointmentEditFormTests(TestCase):
    def setUp(self):
        location = get_test_location()
        self.user = create_user()

        worker = Worker.get_by_user(self.user)
        worker.locations = [get_test_location()]
        worker.save()

        self.visit = create_visit()

        self.sample_data = {'first_name': 'name',
                            'length': '50',
                            'location': location.id,
                            'datetime_when': "2020-01-01",
                            }
        self.sample_data_with_status = self.sample_data
        self.sample_data_with_status['status'] = Appointment.APPOINTMENT_STATUS_NO_SHOW
        add_form = AppointmentAddForm(user=self.user, data=self.sample_data)
        add_form.instance.visit_id = self.visit.id
        self.appointment = add_form.save()

    def test_validation(self):
        form = AppointmentEditForm(user=self.user, data=self.sample_data_with_status)
        self.assertTrue(form.is_valid())

    def test_no_visit_field(self):
        form = AppointmentEditForm(user=self.user, data=self.sample_data_with_status)
        self.assertNotIn('visit', form.fields)

    def test_validation_invalid_location(self):
        self.sample_data['location'] = create_location(name="xxx").id
        form = AppointmentEditForm(user=self.user, data=self.sample_data_with_status)

        self.assertFalse(form.is_valid())
        self.assertTrue("location" in form.errors)
