from django.test import TestCase

from functions import get_test_location
from web.forms import SubjectAddForm
from web.forms import SubjectEditForm
from web.models import Subject
from web.models.constants import SEX_CHOICES_MALE, SUBJECT_TYPE_CHOICES_CONTROL


class SubjectEditFormTests(TestCase):
    def setUp(self):
        location = get_test_location()
        self.sample_data = {'first_name': 'name',
                            'last_name': 'name',
                            'sex': SEX_CHOICES_MALE,
                            'type': SUBJECT_TYPE_CHOICES_CONTROL,
                            'default_location': location.id,
                            'country': 'Luxembourg',
                            'screening_number': '123',
                            'nd_number': 'nd_123'
                            }

    def tearDown(self):
        Subject.objects.all().delete()

    def test_validation(self):
        add_form = SubjectAddForm(data=self.sample_data)
        subject = add_form.save()
        self.sample_data['id'] = subject.id

        edit_form = SubjectEditForm(self.sample_data)
        save_status = edit_form.is_valid()
        self.assertTrue(save_status)

    def test_invalid_nd_number_edit(self):
        add_form = SubjectAddForm(data=self.sample_data)
        add_form.save()

        self.sample_data['nd_number'] = "nd_124"
        self.sample_data['screening_number'] = "124"
        add_form = SubjectAddForm(data=self.sample_data)
        subject = add_form.save()

        self.sample_data['id'] = subject.id
        self.sample_data['nd_number'] = "nd_123"
        edit_form = SubjectEditForm(self.sample_data)

        save_status = edit_form.is_valid()
        self.assertFalse(save_status)
