# coding=utf-8
from django.shortcuts import redirect, get_object_or_404

from . import wrap_response
from ..forms import WorkerAddForm, WorkerEditForm, WorkerDetailForm
from ..models import Worker, Avaibility


def doctors(request):
    doctors_list = Worker.objects.order_by('-last_name')
    context = {
        'doctors_list': doctors_list
    }

    return wrap_response(request, "doctors/index.html", context)


def doctor_add(request):
    if request.method == 'POST':
        form = WorkerAddForm(request.POST, request.FILES)
        if form.is_valid():
            form.save()
            return redirect('web.views.doctors')
    else:
        form = WorkerAddForm()

    return wrap_response(request, 'doctors/add.html', {'form': form})


def doctor_edit(request, doctor_id):
    the_doctor = get_object_or_404(Worker, id=doctor_id)
    if request.method == 'POST':
        form = WorkerEditForm(request.POST, request.FILES, instance=the_doctor)
        if form.is_valid():
            form.save()
            return redirect('web.views.doctors')
    else:
        form = WorkerEditForm(instance=the_doctor)
    return wrap_response(request, 'doctors/edit.html', {'form': form})


def doctor_details(request, doctor_id):
    the_doctor = get_object_or_404(Worker, id=doctor_id)
    form = WorkerDetailForm(instance=the_doctor)

    return wrap_response(request, 'doctors/details.html', {'form': form})


def doctor_availability(request, doctor_id):
    avall = Avaibility.objects.filter(person=doctor_id)

    avmon = avall.filter(day_number=1)
    avtue = avall.filter(day_number=2)
    avwed = avall.filter(day_number=3)
    avthu = avall.filter(day_number=4)
    avfri = avall.filter(day_number=5)
    avsat = avall.filter(day_number=6)
    avsun = avall.filter(day_number=7)

    context = {
        'avmon': avmon,
        'avtue': avtue,
        'avwed': avwed,
        'avthu': avthu,
        'avfri': avfri,
        'avsat': avsat,
        'avsun': avsun,
        'id': doctor_id
    }

    return wrap_response(request, "doctors/availability_index.html", context)


def doctor_availability_delete(request, doctor_id, availability_id):
    availibility = Avaibility.objects.filter(id=availability_id)
    if len(availibility) > 0:
        availibility.delete()
    return redirect(doctoravail, id=doctor_id)  # FIXME doctoravail doesn't exist
